@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Jérémie Galarneau <jeremie.galarneau@efficios.com>
+ * SPDX-FileCopyrightText: 2020 Jérémie Galarneau <jeremie.galarneau@efficios.com>
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,12 +8,13 @@
 #include "tracepoint-trigger-example.h"
 
 #include <lttng/tracepoint.h>
+
 #include <stdio.h>
 #include <sys/time.h>
 #include <time.h>
 #include <unistd.h>
 
-int main(int argc, char **argv)
+int main(void)
 {
 	uint64_t i;
 
@@ -25,10 +26,10 @@ int main(int argc, char **argv)
 		gettimeofday(&tv, NULL);
 		the_time = tv.tv_sec;
 
-		strftime(time_str, sizeof(time_str), "[%m-%d-%Y] %T",
-				localtime(&the_time));
+		strftime(time_str, sizeof(time_str), "[%m-%d-%Y] %T", localtime(&the_time));
 		printf("%s.%ld - Tracing event \"trigger_example:my_event\"\n",
-				time_str, tv.tv_usec);
+		       time_str,
+		       tv.tv_usec);
 
 		tracepoint(trigger_example, my_event, i);
 		sleep(2);
