@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 David Goulet <dgoulet@efficios.com>
+ * SPDX-FileCopyrightText: 2014 David Goulet <dgoulet@efficios.com>
  *
  * SPDX-License-Identifier: LGPL-2.1-only
  *
@@ -9,9 +9,7 @@
 #define LTTNG_CONSTANT_H
 
 #ifndef LTTNG_DEPRECATED
-#if defined (__GNUC__) \
-	&& ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 5)  \
-			|| __GNUC__ >= 5)
+#if defined(__GNUC__) && ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 5) || __GNUC__ >= 5)
 #define LTTNG_DEPRECATED(msg) __attribute__((deprecated(msg)))
 #else
 #define LTTNG_DEPRECATED(msg) __attribute__((deprecated))
@@ -32,19 +30,28 @@
 #endif /* #else #ifndef __STDC_LIMIT_MACROS */
 #include <sys/types.h>
 
-/*
- * Event symbol length. Copied from LTTng kernel ABI.
- */
-#define LTTNG_SYMBOL_NAME_LEN			256
+/*!
+@brief
+    Maximum symbol length.
+
+@ingroup api_gen
+*/
+#define LTTNG_SYMBOL_NAME_LEN 256
 
 /*
  * PROC(5) mentions that PID_MAX_LIMIT may not exceed 2^22 on 64-bit HW.
  * We prefer to use 32-bits for simplicity's sake.
  */
-#define LTTNG_MAX_PID				INT32_MAX
-#define LTTNG_MAX_PID_STR			"2147483647"
+#define LTTNG_MAX_PID	  INT32_MAX
+#define LTTNG_MAX_PID_STR "2147483647"
 
-#define LTTNG_NAME_MAX				255
+/*!
+@brief
+    Maximum name length.
+
+@ingroup api_gen
+*/
+#define LTTNG_NAME_MAX 255
 
 /*
  * POSIX guarantees that a host name will not exceed 255 characters.
@@ -53,8 +60,8 @@
  *
  * 256 is used to include a trailing NULL character.
  */
-#define LTTNG_HOST_NAME_MAX			256
+#define LTTNG_HOST_NAME_MAX 256
 
-#define LTTNG_PATH_MAX				4096
+#define LTTNG_PATH_MAX 4096
 
 #endif /* LTTNG_CONSTANT_H */
