@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 David Goulet <dgoulet@efficios.com>
+ * SPDX-FileCopyrightText: 2013 David Goulet <dgoulet@efficios.com>
  *
  * SPDX-License-Identifier: LGPL-2.1-only
  *
@@ -8,6 +8,8 @@
 #ifndef LTTNG_SNAPSHOT_H
 #define LTTNG_SNAPSHOT_H
 
+#include <lttng/lttng-export.h>
+
 #include <limits.h>
 #include <stdint.h>
 #include <sys/types.h>
@@ -26,12 +28,12 @@ struct lttng_snapshot_output_list;
 /*
  * Return an newly allocated snapshot output object or NULL on error.
  */
-extern struct lttng_snapshot_output *lttng_snapshot_output_create(void);
+LTTNG_EXPORT extern struct lttng_snapshot_output *lttng_snapshot_output_create(void);
 
 /*
  * Free a given snapshot output object.
  */
-extern void lttng_snapshot_output_destroy(struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern void lttng_snapshot_output_destroy(struct lttng_snapshot_output *output);
 
 /*
  * Snapshot output getter family functions. They all return the value present
@@ -39,15 +41,20 @@ extern void lttng_snapshot_output_destroy(struct lttng_snapshot_output *output);
  */
 
 /* Return snapshot ID. */
-extern uint32_t lttng_snapshot_output_get_id(const struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern uint32_t
+lttng_snapshot_output_get_id(const struct lttng_snapshot_output *output);
 /* Return maximum size of a snapshot. */
-extern uint64_t lttng_snapshot_output_get_maxsize(const struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern uint64_t
+lttng_snapshot_output_get_maxsize(const struct lttng_snapshot_output *output);
 /* Return snapshot name. */
-extern const char *lttng_snapshot_output_get_name(const struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern const char *
+lttng_snapshot_output_get_name(const struct lttng_snapshot_output *output);
 /* Return snapshot control URL in a text format. */
-extern const char *lttng_snapshot_output_get_ctrl_url(const struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern const char *
+lttng_snapshot_output_get_ctrl_url(const struct lttng_snapshot_output *output);
 /* Return snapshot data URL in a text format. */
-extern const char *lttng_snapshot_output_get_data_url(const struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern const char *
+lttng_snapshot_output_get_data_url(const struct lttng_snapshot_output *output);
 
 /*
  * Snapshot output setter family functions.
@@ -57,14 +64,14 @@ extern const char *lttng_snapshot_output_get_data_url(const struct lttng_snapsho
  */
 
 /* Set a custom ID. */
-extern int lttng_snapshot_output_set_id(uint32_t id,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_id(uint32_t id,
+						     struct lttng_snapshot_output *output);
 /* Set the maximum size. */
-extern int lttng_snapshot_output_set_size(uint64_t size,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_size(uint64_t size,
+						       struct lttng_snapshot_output *output);
 /* Set the snapshot name. */
-extern int lttng_snapshot_output_set_name(const char *name,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_name(const char *name,
+						       struct lttng_snapshot_output *output);
 
 /*
  * Set the output destination to be a path on the local filesystem.
@@ -73,8 +80,8 @@ extern int lttng_snapshot_output_set_name(const char *name,
  *
  * Return 0 on success or else a negative LTTNG_ERR code.
  */
-extern int lttng_snapshot_output_set_local_path(const char *path,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_local_path(const char *path,
+							     struct lttng_snapshot_output *output);
 
 /*
  * Set the output destination to be the network from a combined control/data
@@ -84,8 +91,8 @@ extern int lttng_snapshot_output_set_local_path(const char *path,
  *
  * Return 0 on success or else a negative LTTNG_ERR code.
  */
-extern int lttng_snapshot_output_set_network_url(const char *url,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_network_url(const char *url,
+							      struct lttng_snapshot_output *output);
 
 /*
  * Set the output destination to be the network using separate URLs for control
@@ -97,32 +104,31 @@ extern int lttng_snapshot_output_set_network_url(const char *url,
  *
  * Return 0 on success or else a negative LTTNG_ERR code.
  */
-extern int lttng_snapshot_output_set_network_urls(
-		const char *ctrl_url, const char *data_url,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_network_urls(
+	const char *ctrl_url, const char *data_url, struct lttng_snapshot_output *output);
 
 /* Set the control URL. Local and remote URL are supported. */
-extern int lttng_snapshot_output_set_ctrl_url(const char *url,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_ctrl_url(const char *url,
+							   struct lttng_snapshot_output *output);
 /* Set the data URL. Local and remote URL are supported. */
-extern int lttng_snapshot_output_set_data_url(const char *url,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_output_set_data_url(const char *url,
+							   struct lttng_snapshot_output *output);
 
 /*
  * Add an output object to a session identified by name.
  *
  * Return 0 on success or else a negative LTTNG_ERR code.
  */
-extern int lttng_snapshot_add_output(const char *session_name,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_add_output(const char *session_name,
+						  struct lttng_snapshot_output *output);
 
 /*
  * Delete an output object to a session identified by name.
  *
  * Return 0 on success or else a negative LTTNG_ERR code.
  */
-extern int lttng_snapshot_del_output(const char *session_name,
-		struct lttng_snapshot_output *output);
+LTTNG_EXPORT extern int lttng_snapshot_del_output(const char *session_name,
+						  struct lttng_snapshot_output *output);
 
 /*
  * List all snapshot output(s) of a session identified by name. The output list
@@ -131,8 +137,8 @@ extern int lttng_snapshot_del_output(const char *session_name,
  * Return 0 on success or else a negative LTTNG_ERR code and the list pointer
  * is untouched.
  */
-extern int lttng_snapshot_list_output(const char *session_name,
-		struct lttng_snapshot_output_list **list);
+LTTNG_EXPORT extern int lttng_snapshot_list_output(const char *session_name,
+						   struct lttng_snapshot_output_list **list);
 
 /*
  * Return the next available snapshot output object in the given list. A list
@@ -141,13 +147,14 @@ extern int lttng_snapshot_list_output(const char *session_name,
  * Return the next object on success or else NULL indicating the end of the
  * list.
  */
-extern struct lttng_snapshot_output *lttng_snapshot_output_list_get_next(
-		struct lttng_snapshot_output_list *list);
+LTTNG_EXPORT extern struct lttng_snapshot_output *
+lttng_snapshot_output_list_get_next(struct lttng_snapshot_output_list *list);
 
 /*
  * Free an output list object.
  */
-extern void lttng_snapshot_output_list_destroy(struct lttng_snapshot_output_list *list);
+LTTNG_EXPORT extern void
+lttng_snapshot_output_list_destroy(struct lttng_snapshot_output_list *list);
 
 /*
  * Snapshot a trace for the given session.
@@ -161,8 +168,8 @@ extern void lttng_snapshot_output_list_destroy(struct lttng_snapshot_output_list
  *
  * Return 0 on success or else a negative LTTNG_ERR value.
  */
-extern int lttng_snapshot_record(const char *session_name,
-		struct lttng_snapshot_output *output, int wait);
+LTTNG_EXPORT extern int
+lttng_snapshot_record(const char *session_name, struct lttng_snapshot_output *output, int wait);
 
 #ifdef __cplusplus
 }
