@@ -1,5 +1,5 @@
-# Copyright (C) 2012 Christian Babeux <christian.babeux@efficios.com>
-# Copyright (C) 2014 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
+# SPDX-FileCopyrightText: 2012 Christian Babeux <christian.babeux@efficios.com>
+# SPDX-FileCopyrightText: 2014 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
 #
 # SPDX-License-Identifier: GPL-2.0-only
 
@@ -8,7 +8,7 @@ UST_EVENT_NAME="tp:tptest"
 KERNEL_EVENT_NAME="sched_switch"
 CHANNEL_NAME="testchan"
 HEALTH_CHECK_BIN="health_check"
-NUM_TESTS=99
+NUM_TESTS=90
 SLEEP_TIME=30
 
 source $TESTDIR/utils/utils.sh
@@ -82,7 +82,7 @@ function test_health
 		diag "With UST consumer daemons"
 		enable_ust_lttng_event_ok $SESSION_NAME $UST_EVENT_NAME $CHANNEL_NAME
 
-		skip $isroot "Root access is needed. Skipping kernel consumer health check test." "1" ||
+		check_skip_kernel_test "1" "Skipping kernel consumer health check test." ||
 		{
 			diag "With kernel consumer daemon"
 			lttng_enable_kernel_event $SESSION_NAME $KERNEL_EVENT_NAME $CHANNEL_NAME
@@ -94,7 +94,10 @@ function test_health
 		diag "With relay daemon"
 		RELAYD_ARGS="--relayd-path=${LTTNG_RELAYD_HEALTH}"
 
-		start_lttng_relayd "-o $TRACE_PATH"
+		# When starting with the error test points the "start" can fail
+		# or hang waiting for the PID file which got cleaned up quickly.
+		# Use the background mode with no tap to avoid the hang and failure.
+		start_lttng_relayd_opt 0 "-b" "-o $TRACE_PATH"
 	else
 		RELAYD_ARGS=
 	fi
@@ -113,7 +116,7 @@ function test_health
 
 
 	if [ ${test_needs_root} -eq 1 ]; then
-		skip ${isroot} "Root access needed for test \"${test_thread_name}\"." "1" ||
+		check_skip_kernel_test "1" "Skipping \"${test_thread_name}\"." ||
 		{
 			report_errors "${test_thread_error_string}" "${test_relayd}"
 		}
@@ -151,10 +154,10 @@ fi
 
 skip $foundobj "No shared object generated. Skipping all tests." $NUM_TESTS && exit 0
 
-THREAD=("LTTNG_SESSIOND_THREAD_MANAGE_CLIENTS"
+THREAD=(
+	"LTTNG_SESSIOND_THREAD_MANAGE_CLIENTS"
 	"LTTNG_SESSIOND_THREAD_MANAGE_APPS"
 	"LTTNG_SESSIOND_THREAD_REG_APPS"
-	"LTTNG_SESSIOND_THREAD_HT_CLEANUP"
 	"LTTNG_SESSIOND_THREAD_APP_MANAGE_NOTIFY"
 	"LTTNG_SESSIOND_THREAD_APP_REG_DISPATCH"
 	"LTTNG_SESSIOND_THREAD_MANAGE_KERNEL"
@@ -175,7 +178,6 @@ ERROR_STRING=(
 	"Thread \"Session daemon command\" is not responding in component \"sessiond\"."
 	"Thread \"Session daemon application manager\" is not responding in component \"sessiond\"."
 	"Thread \"Session daemon application registration\" is not responding in component \"sessiond\"."
-	"Thread \"Session daemon hash table cleanup\" is not responding in component \"sessiond\"."
 	"Thread \"Session daemon application notification manager\" is not responding in component \"sessiond\"."
 	"Thread \"Session daemon application registration dispatcher\" is not responding in component \"sessiond\"."
 	"Thread \"Session daemon kernel\" is not responding in component \"sessiond\"."
@@ -214,7 +216,6 @@ NEEDS_ROOT=(
 	0
 	0
 	0
-	0
 	1
 
 	0
@@ -236,7 +237,6 @@ TEST_CONSUMERD=(
 	0
 	0
 	0
-	0
 
 	1
 	1
@@ -257,7 +257,6 @@ TEST_RELAYD=(
 	0
 	0
 	0
-	0
 
 	0
 	0
@@ -271,16 +270,10 @@ TEST_RELAYD=(
 	1
 )
 
-STDOUT_PATH=$(mktemp --tmpdir tmp.test_health_stdout_path.XXXXXX)
-STDERR_PATH=$(mktemp --tmpdir tmp.test_health_stderr_path.XXXXXX)
-TRACE_PATH=$(mktemp --tmpdir -d tmp.test_health_trace_path.XXXXXX)
-HEALTH_PATH=$(mktemp --tmpdir -d tmp.test_health_trace_path.XXXXXX)
-
-if [ "$(id -u)" == "0" ]; then
-	isroot=1
-else
-	isroot=0
-fi
+STDOUT_PATH=$(mktemp -t tmp.test_health_stdout_path.XXXXXX)
+STDERR_PATH=$(mktemp -t tmp.test_health_stderr_path.XXXXXX)
+TRACE_PATH=$(mktemp -d -t tmp.test_health_trace_path.XXXXXX)
+HEALTH_PATH=$(mktemp -d -t tmp.test_health_trace_path.XXXXXX)
 
 THREAD_COUNT=${#THREAD[@]}
 i=0
