@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# Copyright (C) 2019 Jonathan Rajotte <jonathan.rajotte-julien@efficios.com>
+# SPDX-FileCopyrightText: 2019 Jonathan Rajotte <jonathan.rajotte-julien@efficios.com>
 #
 # SPDX-License-Identifier: LGPL-2.1-only
 
@@ -11,7 +11,7 @@ function get_env_value ()
 	local result
 	local ret
 
-	result=$(grep "$key" < "$env_file")
+	result=$(grep "$key =" < "$env_file")
 	ret=$?
 	if [ $ret -eq 1 ]; then
 		echo "invalid_value_extraction"
