@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 Antoine Busque <abusque@efficios.com>
+ * SPDX-FileCopyrightText: 2015 Antoine Busque <abusque@efficios.com>
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,18 +16,11 @@
 
 #include <lttng/tracepoint.h>
 
-TRACEPOINT_EVENT(
-		my_provider,
-		my_first_tracepoint,
-		TP_ARGS(
-		int, my_integer_arg,
-		char*, my_string_arg
-	),
-	TP_FIELDS(
-		ctf_string(my_string_field, my_string_arg)
-		ctf_integer(int, my_integer_field, my_integer_arg)
-	)
-)
+TRACEPOINT_EVENT(my_provider,
+		 my_first_tracepoint,
+		 TP_ARGS(int, my_integer_arg, char *, my_string_arg),
+		 TP_FIELDS(ctf_string(my_string_field, my_string_arg)
+				   ctf_integer(int, my_integer_field, my_integer_arg)))
 
 #endif /* _TP_H */
 
