@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009  Pierre-Marc Fournier
+ * SPDX-FileCopyrightText: 2009 Pierre-Marc Fournier
  * Copyright (C) 2011-2012  Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  *
  * SPDX-License-Identifier: LGPL-2.1-only
@@ -7,23 +7,18 @@
  */
 
 #include <stdio.h>
-#include <unistd.h>
-#include <sys/types.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #define TRACEPOINT_DEFINE
 #define TRACEPOINT_CREATE_PROBES
 #include "ust_tests_daemon.h"
 
-int main(int argc, char **argv, char *env[])
+int main(void)
 {
 	int result;
 
-	if (argc < 1) {
-		fprintf(stderr, "usage: daemon\n");
-		exit(1);
-	}
-
 	pid_t parent_pid = getpid();
 	printf("parent_pid %d\n", parent_pid);
 	tracepoint(ust_tests_daemon, before_daemon, parent_pid);
