@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
+ * SPDX-FileCopyrightText: 2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,26 +12,20 @@
 #define _TRACEPOINT_UST_TESTS_DAEMON_H
 
 #include <lttng/tracepoint.h>
+
 #include <sys/types.h>
 
-TRACEPOINT_EVENT(ust_tests_daemon, before_daemon,
-	TP_ARGS(pid_t, pid),
-	TP_FIELDS(
-		ctf_integer(pid_t, pid, pid)
-	)
-)
+TRACEPOINT_EVENT(ust_tests_daemon,
+		 before_daemon,
+		 TP_ARGS(pid_t, pid),
+		 TP_FIELDS(ctf_integer(pid_t, pid, pid)))
 
-TRACEPOINT_EVENT(ust_tests_daemon, after_daemon_child,
-	TP_ARGS(pid_t, pid),
-	TP_FIELDS(
-		ctf_integer(pid_t, pid, pid)
-	)
-)
+TRACEPOINT_EVENT(ust_tests_daemon,
+		 after_daemon_child,
+		 TP_ARGS(pid_t, pid),
+		 TP_FIELDS(ctf_integer(pid_t, pid, pid)))
 
-TRACEPOINT_EVENT(ust_tests_daemon, after_daemon_parent,
-	TP_ARGS(),
-	TP_FIELDS()
-)
+TRACEPOINT_EVENT(ust_tests_daemon, after_daemon_parent, TP_ARGS(), TP_FIELDS())
 
 #endif /* _TRACEPOINT_UST_TESTS_DAEMON_H */
 
