@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Pierre-Marc Fournier
+ * SPDX-FileCopyrightText: 2009 Pierre-Marc Fournier
  *
  * SPDX-License-Identifier: LGPL-2.1-only
  *
@@ -12,7 +12,7 @@
 #define TRACEPOINT_CREATE_PROBES
 #include "ust_tests_fork.h"
 
-int main(int argc, char **argv)
+int main(void)
 {
 	printf("IN FORK2\n");
 
