@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012 David Goulet <dgoulet@efficios.com>
+ * SPDX-FileCopyrightText: 2012 David Goulet <dgoulet@efficios.com>
  *
  * SPDX-License-Identifier: LGPL-2.1-only
  *
@@ -16,7 +16,7 @@
 /*
  * Thread recording a tracepoint every minute for 20 minutes.
  */
-static void *th_event_minute(void *data)
+static void *th_event_minute(void *data __attribute__((unused)))
 {
 	int i;
 
@@ -45,7 +45,7 @@ static void *th_event_minute(void *data)
 /*
  * main
  */
-int main(int argc, char **argv)
+int main(void)
 {
 	int ret;
 	void *status;
