@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
+ * SPDX-FileCopyrightText: 2011 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,31 +13,29 @@
 
 #include <lttng/tracepoint.h>
 
-TRACEPOINT_EVENT(ust_tests_demo, starting,
-	TP_ARGS(int, value),
-	TP_FIELDS(
-		ctf_integer(int, value, value)
-	)
-)
+TRACEPOINT_EVENT(ust_tests_demo,
+		 starting,
+		 TP_ARGS(int, value),
+		 TP_FIELDS(ctf_integer(int, value, value)))
 TRACEPOINT_LOGLEVEL(ust_tests_demo, starting, TRACE_CRIT)
 
 /*
  * Dummy model information, just for example. TODO: we should check if
  * EMF model URI have some standard format we should follow.
  */
-TRACEPOINT_MODEL_EMF_URI(ust_tests_demo, starting,
-	"http://example.com/path_to_model?q=ust_tests_demo:starting")
+TRACEPOINT_MODEL_EMF_URI(ust_tests_demo,
+			 starting,
+			 "http://example.com/path_to_model?q=ust_tests_demo:starting")
 
-TRACEPOINT_EVENT(ust_tests_demo, done,
-	TP_ARGS(int, value),
-	TP_FIELDS(
-		ctf_integer(int, value, value)
-	)
-)
+TRACEPOINT_EVENT(ust_tests_demo,
+		 done,
+		 TP_ARGS(int, value),
+		 TP_FIELDS(ctf_integer(int, value, value)))
 TRACEPOINT_LOGLEVEL(ust_tests_demo, done, TRACE_CRIT)
 
-TRACEPOINT_MODEL_EMF_URI(ust_tests_demo, done,
-	"http://example.com/path_to_model?q=ust_tests_demo:done")
+TRACEPOINT_MODEL_EMF_URI(ust_tests_demo,
+			 done,
+			 "http://example.com/path_to_model?q=ust_tests_demo:done")
 
 #endif /* _TRACEPOINT_UST_TESTS_DEMO_H */
 
