@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 Jérémie Galarneau <jeremie.galarneau@efficios.com>
+ * SPDX-FileCopyrightText: 2016 Jérémie Galarneau <jeremie.galarneau@efficios.com>
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,12 +16,7 @@
 
 #include <lttng/tracepoint.h>
 
-TRACEPOINT_EVENT(
-    libbar,
-    bar,
-    TP_ARGS(void),
-    TP_FIELDS()
-)
+TRACEPOINT_EVENT(libbar, bar, TP_ARGS(void), TP_FIELDS())
 
 #endif /* _LIBBAR_TP_H */
 
