@@ -1,17 +1,17 @@
 /*
- * Copyright (C) 2016 Antoine Busque <abusque@efficios.com>
+ * SPDX-FileCopyrightText: 2016 Antoine Busque <abusque@efficios.com>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  *
  */
 
 /* _GNU_SOURCE is defined by config.h */
+#include <common/compat/errno.hpp>
+
 #include <dlfcn.h>
 #include <stdio.h>
-#include <unistd.h>
 #include <stdlib.h>
-
-#include <common/compat/errno.h>
+#include <unistd.h>
 
 /*
  * libfoo has a direct dependency on libbar.
@@ -19,7 +19,7 @@
  * This test is therefore a mix of dlopen/dlclose and dlmopen/dlclose of
  * libfoo, and of its direct dependencies.
  */
-int main(int argc, char **argv)
+int main(void)
 {
 	void *h0, *h2, *h3, *h4;
 
