@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# Copyright 2010 Patrick LeBoutillier <patrick.leboutillier@gmail.com>
+# SPDX-FileCopyrightText: 2010 Patrick LeBoutillier <patrick.leboutillier@gmail.com>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -14,8 +14,10 @@ _test_died=0
 _expected_tests=0
 _executed_tests=0
 _failed_tests=0
+_auto_timing="${LTTNG_TESTS_TAP_AUTOTIME:-1}"
+_last_time=''
 TODO=
-
+TIME_SCRIPT="$(realpath -e -- "$(dirname "${BASH_SOURCE[0]}")")/clock"
 
 usage(){
     cat <<'USAGE'
@@ -25,6 +27,7 @@ PLAN:
   plan_no_plan
   plan_skip_all [REASON]
   plan_tests NB_TESTS
+  tap_disable
 
 TEST:
   ok RESULT [NAME]
@@ -52,6 +55,7 @@ TODO:
 
 OTHER:
   diag MSG
+  autotime 0|1
 
 EXAMPLE:
   #!/bin/bash
@@ -99,17 +103,22 @@ unset opt set_u
 # Used to call _cleanup on shell exit
 trap _exit EXIT
 
+tap_disable() {
+  trap - EXIT
+}
 
 plan_no_plan(){
     (( _plan_set != 0 )) && "You tried to plan twice!"
 
     _plan_set=1
     _no_plan=1
+    _last_time=$("${TIME_SCRIPT}")
 
     return 0
 }
 
 
+
 plan_skip_all(){
     local reason=${1:-''}
 
@@ -119,6 +128,7 @@ plan_skip_all(){
 
     _skip_all=1
     _plan_set=1
+    _last_time=$("${TIME_SCRIPT}")
     _exit 0
 
     return 0
@@ -133,6 +143,7 @@ plan_tests(){
     _print_plan $tests
     _expected_tests=$tests
     _plan_set=1
+    _last_time=$("${TIME_SCRIPT}")
 
     return $tests
 }
@@ -195,6 +206,7 @@ ok(){
     fi
 
     echo
+    _autotime
     if (( result != 0 )) ; then
         local file='tap-functions'
         local func=
@@ -233,6 +245,7 @@ okx(){
         diag "$line"
     done
     ok ${PIPESTATUS[0]} "$command"
+    _autotime
 }
 
 
@@ -342,6 +355,7 @@ skip(){
         for (( i=0 ; i<$n ; i++ )) ; do
             _executed_tests=$(( _executed_tests + 1 ))
             echo "ok $_executed_tests # skip: $reason"
+            _autotime
         done
         return 0
     else
@@ -349,6 +363,32 @@ skip(){
     fi
 }
 
+_autotime(){
+    local new_time
+    local duration
+
+    if [ "${_auto_timing}" -eq "1" ] ; then
+        new_time=$("${TIME_SCRIPT}")
+        duration=$(awk "BEGIN { printf(\"%f\n\", ($new_time - $_last_time)*1000) }")
+        echo "  ---"
+        echo "    duration_ms: ${duration}"
+        echo "  ..."
+    fi
+    _last_time=$("${TIME_SCRIPT}")
+    return 0
+}
+
+
+autotime(){
+    local val=${1:?}
+
+    if [[ "${val}" != "0" ]] ; then
+        _auto_timing=1
+    else
+        _auto_timing=0;
+    fi
+    return 0
+}
 
 diag(){
     local msg=${1:?}
@@ -381,6 +421,11 @@ BAIL_OUT(){
 _cleanup(){
     local rc=0
 
+    if (( _plan_set == 0 )) ; then
+        diag "Looks like your test died before it could output anything."
+        return $rc
+    fi
+
     if (( _test_died != 0 )) ; then
         diag "Looks like your test died just after $_executed_tests."
         return $rc
