@@ -1,19 +1,21 @@
 /*
- * Copyright (C) 2018 Francis Deslauriers <francis.deslauriers@efficios.com>
+ * SPDX-FileCopyrightText: 2018 Francis Deslauriers <francis.deslauriers@efficios.com>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
-#include "test_class.h"
+#include "test_class.hpp"
 
 volatile int not_a_function = 0;
-void __attribute__ ((noinline))  test_cxx_function()
+
+void test_cxx_function() __attribute__((noinline));
+void test_cxx_function()
 {
 	not_a_function += 1;
 }
 
-int main(int argc, char *argv[])
+int main()
 {
 	test_class my_test_class;
 	/* Call test function. */
